/* Copyright (C) 1992 Free Software Foundation, Inc.
This file is part of the GNU C Library.

The GNU C Library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public License as
published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version.

The GNU C Library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with the GNU C Library; see the file COPYING.LIB.  If
not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.  */

/* In various parts of this file we define the System V values for
   things as <whatever>.  Those are the values that System V
   uses for termio, and also (SVR4) termios.  Not necessarily the
   same as the GNU termios that the library user sees.  */

/* Number of elements of c_cc.  termio only.  */
#define NCC 8

#define VINTR 0
#define VQUIT 1
#define VERASE 2
#define VKILL 3
#define VEOF 4
/* This field means VEOF if ICANON, VMIN if not.  */
#define VMIN 4
#define VEOL 5
/* This field means VEOL if ICANON, VTIME if not.  */
#define VTIME 5
#define VEOL2 6

/* Flags in c_iflag.  */
#define IGNBRK 1
#define BRKINT 2
#define IGNPAR 4
#define PARMRK 8
#define INPCK 0x10
#define ISTRIP 0x20
#define INLCR 0x40
#define IGNCR 0x80
#define ICRNL 0x100
#define IUCLC 0x200
#define IXON 0x400
#define IXANY 0x800
#define IXOFF 0x1000
#define IMAXBEL 0x2000

/* Flags in c_cflag.  */
#define CBAUD 0xf
#define CIBAUD 0xf0000	/* termios only.  */
#define IBSHIFT 16
/* Values for CBAUD and CIBAUD.  */
#define B0 0
#define B50 1
#define B75 2
#define B110 3
#define B134 4
#define B150 5
#define B200 6
#define B300 7
#define B600 8
#define B1200 9
#define B1800 10
#define B2400 11
#define B4800 12
#define B9600 13
#define B19200 14
#define B38400 15

#define CS5 0
#define CS6 0x10
#define CS7 0x20
#define CS8 0x30
#define CSIZE 0x30
#define CSTOPB 0x40
#define CREAD 0x80
#define PARENB 0x100
#define PARODD 0x200
#define HUPCL 0x400
#define CLOCAL 0x800

/* Flags in c_lflag.  */
#define ISIG 1
#define ICANON 2
#define ECHO 8
#define ECHOE 0x10
#define ECHOK 0x20
#define ECHONL 0x40
#define NOFLSH 0x80
#define TOSTOP 0x100
#define ECHOCTL 0x200
#define ECHOPRT 0x400
#define ECHOKE 0x800
#define FLUSHO 0x2000
#define PENDIN 0x4000
#define IEXTEN 0x8000

/* Flags in c_oflag.  */
#define OPOST 1
#define OLCUC 2
#define ONLCR 4
#define NLDLY 0x100
#define NL0 0
#define NL1 0x100
#define CRDLY 0x600
#define CR0 0
#define CR1 0x200
#define CR2 0x400
#define CR3 0x600
#define TABDLY 0x1800
#define TAB0 0
#define TAB1 0x0800
#define TAB2 0x1000
/* TAB3 is an obsolete name for XTABS.  But we provide it since some
   programs expect it to exist.  */
#define TAB3 0x1800
#define XTABS 0x1800
#define BSDLY 0x2000
#define BS0 0
#define BS1 0x2000
#define VTDLY 0x4000
#define VT0 0
#define VT1 0x4000
#define FFDLY 0x8000
#define FF0 0
#define FF1 0x8000

/* ioctl's.  */

#define TCGETA 0x5401
#define TCSETA 0x5402
#define TCSETAW 0x5403
#define TCSETAF 0x5404
#define TCSBRK 0x5405
#define TCXONC 0x5406
#define TCFLSH 0x5407
#define TIOCGPGRP 0x7414
#define TIOCSPGRP 0x7415

struct termio
  {
    unsigned short c_iflag;
    unsigned short c_oflag;
    unsigned short c_cflag;
    unsigned short c_lflag;
    char c_line;
    unsigned char c_cc[NCC];
  };
